@@ -49,8 +49,10 @@ print.phylopath <- function(x, ...) {
 #' @export
 show_warnings <- function(phylopath = NULL) {
   if (is.null(phylopath)) phylopath <- .Last.value
-  stopifnot(inherits(phylopath, 'phylopath'))
-  phylopath$warnings
+  if(!inherits(phylopath, 'phylopath'))
+    stop('This function expects a phylopath object.', call. = FALSE)
+  sink <- lapply(phylopath$warnings, warning, .call = FALSE)
+  return(invisible(NULL))
 }
 
 #' Plot a directed acyclic graph.
